[openib-general] [PATCH][14/26] kDAPL: Remove typedef DAT_CR_PARAM

Tom Duffy Tom.Duffy at Sun.COM
Mon May 9 14:39:43 PDT 2005


Signed-off-by: Tom Duffy <tduffy at sun.com>

diff -Nur -X /home/tduffy/dontdiff linux-kernel13/dat/dat.h linux-kernel14/dat/dat.h
--- linux-kernel13/dat/dat.h	2005-05-09 12:54:15.334001000 -0700
+++ linux-kernel14/dat/dat.h	2005-05-09 12:58:35.516881000 -0700
@@ -718,7 +718,7 @@
  * encode it into Private Data.
  */
 
-typedef struct dat_cr_param {
+struct dat_cr_param {
 	/* Remote IA whose Endpoint requested the connection. */
 	DAT_IA_ADDRESS_PTR remote_ia_address_ptr;
 
@@ -739,7 +739,7 @@
 	 * requested connection.
 	 */
 	DAT_EP_HANDLE local_ep_handle;
-} DAT_CR_PARAM;
+};
 
 /************************** Events ******************************/
 
@@ -1125,7 +1125,7 @@
 
 typedef DAT_RETURN (*DAT_GET_HANDLE_TYPE_FUNC) (DAT_HANDLE, DAT_HANDLE_TYPE *);
 
-typedef DAT_RETURN (*DAT_CR_QUERY_FUNC) (DAT_CR_HANDLE,	DAT_CR_PARAM *);
+typedef DAT_RETURN (*DAT_CR_QUERY_FUNC) (DAT_CR_HANDLE, struct dat_cr_param *);
 
 typedef DAT_RETURN (*DAT_CR_ACCEPT_FUNC) (
         DAT_CR_HANDLE, DAT_EP_HANDLE, DAT_COUNT, const DAT_PVOID);
@@ -1457,7 +1457,7 @@
 }
 
 static inline DAT_RETURN dat_cr_query(DAT_CR_HANDLE cr, 
-                                      DAT_CR_PARAM * param)
+                                      struct dat_cr_param *param)
 {
         return DAT_CALL_PROVIDER_FUNC(cr_query_func, cr, param);
 }
diff -Nur -X /home/tduffy/dontdiff linux-kernel13/dat-provider/dapl_cr_query.c linux-kernel14/dat-provider/dapl_cr_query.c
--- linux-kernel13/dat-provider/dapl_cr_query.c	2005-05-04 08:19:32.847977000 -0700
+++ linux-kernel14/dat-provider/dapl_cr_query.c	2005-05-09 12:59:17.398973000 -0700
@@ -34,7 +34,7 @@
 #include "dapl.h"
 #include "dapl_adapter_util.h"
 
-DAT_RETURN dapl_cr_query(DAT_CR_HANDLE cr_handle, DAT_CR_PARAM * cr_param)
+DAT_RETURN dapl_cr_query(DAT_CR_HANDLE cr_handle, struct dat_cr_param *cr_param)
 {
 	DAPL_CR *cr_ptr;
 	DAT_RETURN status;
@@ -60,7 +60,7 @@
                                       &cr_ptr->remote_ia_address);
 
 	/* since the arguments are easily accessible, ignore the mask */
-	memcpy(cr_param, &cr_ptr->param, sizeof(DAT_CR_PARAM));
+	memcpy(cr_param, &cr_ptr->param, sizeof *cr_param);
 
 	status = DAT_SUCCESS;
 
diff -Nur -X /home/tduffy/dontdiff linux-kernel13/test/dapltest/test/dapl_transaction_test.c linux-kernel14/test/dapltest/test/dapl_transaction_test.c
--- linux-kernel13/test/dapltest/test/dapl_transaction_test.c	2005-05-09 12:23:41.376001000 -0700
+++ linux-kernel14/test/dapltest/test/dapl_transaction_test.c	2005-05-09 12:59:53.159964000 -0700
@@ -529,7 +529,7 @@
 
 	if (pt_ptr->local_is_server)
 	{
-	    DAT_CR_PARAM   		    cr_param;
+	    struct dat_cr_param cr_param;
 
 	    if (test_ptr->cmd->use_rsp)
 	    {




More information about the general mailing list
diff -Nur -X /home/tduffy/dontdiff linux-kernel13/dat-provider/dapl.h linux-kernel14/dat-provider/dapl.h
--- linux-kernel13/dat-provider/dapl.h	2005-05-09 12:53:48.318003000 -0700
+++ linux-kernel14/dat-provider/dapl.h	2005-05-09 12:57:28.613033000 -0700
@@ -405,12 +405,12 @@
 struct dapl_cr {
 	DAPL_HEADER header;
 
 	/* for convenience the data is kept as a DAT_CR_PARAM.
 	 * however, the "local_endpoint" field is always NULL
 	 * so this wastes a pointer. This is probably ok to
 	 * simplify code, espedially dat_cr_query.
 	 */
-	DAT_CR_PARAM param;
+	struct dat_cr_param param;
 	/* IB specific fields */
 	ib_cm_handle_t ib_cm_handle;
 
@@ -501,7 +501,7 @@
 
 /* CR Functions */
 
-extern DAT_RETURN dapl_cr_query(DAT_CR_HANDLE, DAT_CR_PARAM *);	
+extern DAT_RETURN dapl_cr_query(DAT_CR_HANDLE, struct dat_cr_param *);	
 
 extern DAT_RETURN dapl_cr_accept(DAT_CR_HANDLE,	/* cr_handle */
 				 DAT_EP_HANDLE,	/* ep_handle */
@@ -405,12 +405,12 @@
 	DAPL_HEADER header;
 
-	/* for convenience the data is kept as a DAT_CR_PARAM.
+	/* for convenience the data is kept as a struct dat_cr_param.
 	 * however, the "local_endpoint" field is always NULL
 	 * so this wastes a pointer. This is probably ok to